@@ -110,7 +110,7 @@ fn canonical() {
         0xc4u8, 0x84, 5, 0xa2, 0x61, b'a', 0x39, 2, 154, 0x61, b'b', 0x46, b'd', b'e', b'f', b'd',
         b'e', b'f', 0x82, 0xf4, 0x65, b'h', b'e', b'l', b'l', b'o', 0xd9, 48, 57, 0xf6,
     ];
-    let complex = CborOwned::canonical(bytes, false).unwrap();
+    let complex = CborOwned::canonical(bytes).unwrap();
 
     assert_eq!(
         complex.to_string(),
@@ -132,7 +132,7 @@ fn canonical() {
 // Test cases below taken from [RFC 8949 Appendix A](https://www.rfc-editor.org/rfc/rfc8949#appendix-A)
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 
-fn hex(s: &str) -> Vec<u8> {
+pub(crate) fn hex(s: &str) -> Vec<u8> {
     let mut v = Vec::new();
     for b in s.as_bytes().chunks(2) {
         v.push(u8::from_str_radix(from_utf8(b).unwrap(), 16).unwrap());
@@ -145,7 +145,7 @@ fn str_to_cbor(s: &str, trusting: bool) -> CborOwned {
     if trusting {
         Cbor::checked(&*v).unwrap().to_owned()
     } else {
-        CborOwned::canonical(v, false).unwrap()
+        CborOwned::canonical(v).unwrap()
     }
 }
 
@@ -272,6 +272,13 @@ fn object() {
         "[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25]"
         ("[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25]"));
 
+    assert_eq!(
+        CborBuilder::new().with_max_definite_size(Some(23))
+            .write_canonical(hex("98190102030405060708090a0b0c0d0e0f101112131415161718181819").as_ref())
+            .unwrap().to_string(),
+        "[_ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25]"
+    );
+
     c!("a0" => () Dict(d) if d.count() == 0 => "{}");
     c!("a201020304" => () Dict(d) if d.count() == 2 => r#"{1: 2, 3: 4}"#);
     c!("a26161016162820203" => () Dict(d) if d.count() == 2 => r#"{"a": 1, "b": [2, 3]}"#);
@@ -288,6 +295,13 @@ fn object() {
         "[_ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25]"
         ("[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25]"));
 
+    assert_eq!(
+            CborBuilder::new().with_max_definite_size(Some(23))
+                .write_canonical(hex("9f0102030405060708090a0b0c0d0e0f101112131415161718181819ff").as_ref())
+                .unwrap().to_string(),
+            "[_ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25]"
+        );
+
     c!("bf61610161629f0203ffff" => () Dict(d) if d.count() == 2 => r#"{_ "a": 1, "b": [_ 2, 3]}"# (r#"{"a": 1, "b": [2, 3]}"#));
     c!("826161bf61626163ff" => () Array(d) if d.count() == 2 => r#"["a", {_ "b": "c"}]"# (r#"["a", {"b": "c"}]"#));
     c!("bf6346756ef563416d7421ff" => () Dict(d) if d.count() == 2 => r#"{_ "Fun": true, "Amt": -2}"# (r#"{"Fun": true, "Amt": -2}"#));
